@@ -4,7 +4,7 @@ import sys
 
 secrets = json.loads(sys.argv[1])
 for key, value in secrets.items():
-    print(f"Setting {key} ...")
+    print(f"Setting {key} ...", flush=True)
     if key == "FIREBASE_SA_CREDENTIALS":
         continue
     else:
