@@ -12,9 +12,6 @@ if [ -z "$PATHS_TO_SEARCH" ]; then
     exit 1
 fi
 
-# 3. Get the latest commit
-LATEST_COMMIT=$(git rev-parse HEAD)
-
 # 4. Get the latest commit in the searched paths
 LATEST_COMMIT_IN_PATH=$(git log -1 --format=format:%H --full-diff $PATHS_TO_SEARCH)
 
@@ -24,4 +21,4 @@ if [ $LATEST_COMMIT != $LATEST_COMMIT_IN_PATH ]; then
 fi
 
 echo "True"
-exit 0
+exit 0
\ No newline at end of file
