@@ -1,11 +1,11 @@
 import os
-from pathlib import Path, PosixPath
+from pathlib import Path
 from typing import List
 
 from cognite.airworkflow.util import env
 
 working_path = env.get_env_value("PWD")
-ROOT_DIR = PosixPath(working_path)
+ROOT_DIR = Path(working_path)
 FUNCTIONS_PATH = ROOT_DIR / "functions"
 IGNORE_MODELS_PATH = ROOT_DIR / ".ignore_models"
 
@@ -28,7 +28,7 @@ def getpathstring(function_names: List[str]) -> None:
     escaped_string = list(map(lambda v: escape_string + v + escape_string, function_names))
     function_names_str = f"[{', '.join(escaped_string)}]"
     final_string = start + function_names_str + "}"
-    print(final_string)
+    print(final_string, flush=True)
 
 
 def get_directory_paths() -> List[str]:
