@@ -9,18 +9,31 @@ from cognite.experimental.data_classes import Function
 from requests.exceptions import ConnectionError
 from urllib3.exceptions import MaxRetryError, ReadTimeoutError
 
-import cognite.airworkflow.constants as constants
+from cognite.airworkflow import constants
 from cognite.airworkflow.util import cdf, env
+from cognite.airworkflow.util.cdf import FuncStatus
 
 CHANNEL = "model_deployment_fails"
 
 
+class DeployError(Exception):
+    pass
+
+
+def validate_secrets(secret_dct):
+    if len(secret_dct) > 5:
+        raise ValueError(f"No more than 5 secrets allowed, got {len(secret_dct)}!")
+
+    for secret in secret_dct:
+        if len(secret) > 15:
+            raise ValueError(f"Secret name is too long (15 characters max): {secret}")
+
+
 def format_secret_names(secrets: Dict[str, str]) -> Dict[str, str]:
     new_secrets = {}
     for key, item in secrets.items():
         new_key = key.lower().replace("_", "-")
         new_secrets[new_key] = item
-
     return new_secrets
 
 
@@ -41,6 +54,7 @@ def delete_function_if_exists(
             client.functions.delete(id=function_id)
         if function_name:
             client.functions.delete(external_id=function_name)
+        time.sleep(5)
 
 
 def deploy_function(
@@ -53,70 +67,45 @@ def deploy_function(
 ) -> None:
     delete_function_if_exists(client, function_name)
     secrets = format_secret_names(secrets)
-    if len(secrets) > 5:
-        raise ValueError("Not more than 5 secrets allowed.")
-    for secret in secrets.keys():
-        if len(secret) > 15:
-            raise ValueError(f"Secret name is too long (15 characters max): {secret}")
-    print("Deploying function ...", flush=True)
-    x = 0
-    y = 0
-    while x < 3:
-        function = None
+    validate_secrets(secrets)
+    print(
+        f"Deploying function using {'OIDC' if oidc else 'API-key'} for function: "
+        f"{function_name} in project: {client.config.project}."
+    )
+    for deploy_try in range(1, 4):
         try:
-            if oidc:
-                print(
-                    f"Creating function using OIDC for function :{function_name} in project :{client.config.project}."
-                )
-            else:
-                print(
-                    f"Creating function using API key for function :{function_name} in project {client.config.project}"
-                )
             function = client.functions.create(
                 name=function_name,
                 file_id=file_id,
                 secrets=secrets,
                 external_id=function_name,
-                api_key=client._config.api_key if not oidc else None,
+                api_key=None if oidc else client._config.api_key,
                 owner=owner,
             )
-            success, function_object = cdf.await_function_deployment(client, function, 900)
-            if not success:
-                if function_object is not None:
-                    print(f"Error while deploying function {function_name} and function_id :{function_object.id}")
-                    print(f"Error message :{function_object.error.message}")
-                    print(f"Error stack trace :{function_object.error.trace}")
-                raise TimeoutError(f"Deployment of function with external id {function_name} timed out or failed.")
+            success, fn_obj = cdf.await_function_deployment(client, function, 1800)  # 30 minutes
+            if success:
+                print(
+                    f"Function {function_name} (id: {function.id}) successfully "
+                    f"created in project {client.config.project}.",
+                    flush=True,
+                )
+                return
+            if fn_obj.status == FuncStatus.FAILED:
+                print(f"Error while deploying function {function_name} and function_id: {fn_obj.id}")
+                print(f"Error message: {fn_obj.error['message']}")
+                print(f"Error stack trace: {fn_obj.error['trace']}")
+                # Raise an error that will be retried:
+                raise DeployError(f"Deployment of function with external id {function_name} failed.")
 
-            print(
-                f"Function {function_name} (id: {function.id}) "
-                + f"successfully created in project {client.config.project}.",
-                flush=True,
-            )
-            x = 3
-        except (
-            TimeoutError,
-            ReadTimeoutError,
-            CogniteAPIError,
-            MaxRetryError,
-            ConnectionError,
-            AttributeError,
-        ) as e:
-            print(e, flush=True)
-            if isinstance(e, CogniteAPIError) and e.code == 400:
-                time.sleep(1)
-                if function is not None:
-                    delete_function_if_exists(client, function_id=function.id)
-                else:
-                    delete_function_if_exists(client, function_name=function_name)
-                y += 1
-                if y > 30:
-                    x += 1
-                    y = 0
-            else:
-                x += 1
-            if x >= 3:
-                raise TimeoutError("Tried to deploy three times and failed.")
+            # Raise an error that will NOT be retried:
+            raise TimeoutError(f"Deployment of function with external id {function_name} timed out.")
+
+        except (DeployError, ReadTimeoutError, CogniteAPIError, MaxRetryError, ConnectionError) as e:
+            print(f"Error happened during deployment: {e!r}", flush=True)
+            delete_function_if_exists(client, function_name)
+            if deploy_try >= 3:
+                raise TimeoutError("Max function deploy retry count reached!") from e
+            time.sleep(10)
 
 
 def delete_function(client: CogniteClient, external_id: str):
