@@ -21,7 +21,10 @@ def get_url_dict() -> Dict:
     except FileNotFoundError:
         print("Please put the repoconfig.yaml in the main directory structure")
         sys.exit(1)
+    return load_url_dict(repo_config_path)
 
+
+def load_url_dict(repo_config_path):
     yamlload = load_yaml(repo_config_path)
 
     try:
